@@ -1,4 +1,6 @@
-package WWW::NOS::Open::DayGuide v1.0.3;  # -*- cperl; cperl-indent-level: 4 -*-
+# -*- cperl; cperl-indent-level: 4 -*-
+# Copyright (C) 2011-2021, Roland van Ipenburg
+package WWW::NOS::Open::DayGuide v1.0.4;
 use strict;
 use warnings;
 
@@ -46,7 +48,7 @@ __END__
 
 =encoding utf8
 
-=for stopwords DateTime Ipenburg MERCHANTABILITY
+=for stopwords Bitbucket DateTime Ipenburg MERCHANTABILITY
 
 =head1 NAME
 
@@ -54,7 +56,7 @@ WWW::NOS::Open::DayGuide - client side television or radio program guide
 
 =head1 VERSION
 
-This document describes WWW::NOS::Open::DayGuide version v1.0.3.
+This document describes WWW::NOS::Open::DayGuide version C<v1.0.4>.
 
 =head1 SYNOPSIS
 
@@ -111,15 +113,15 @@ L<WWW::NOS::Open::Broadcast|WWW::NOS::Open::Broadcast> objects.
 =head1 BUGS AND LIMITATIONS
 
 Please report any bugs or feature requests at
-L<RT for rt.cpan.org|https://rt.cpan.org/Dist/Display.html?Queue=WWW-NOS-Open>.
+L<Bitbucket|https://bitbucket.org/rolandvanipenburg/www-nos-open/issues>.
 
 =head1 AUTHOR
 
-Roland van Ipenburg, E<lt>ipenburg@xs4all.nlE<gt>
+Roland van Ipenburg, E<lt>roland@rolandvanipenburg.comE<gt>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2012 by Roland van Ipenburg
+Copyright 2011-2021 by Roland van Ipenburg
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.14.0 or,
