@@ -1,5 +1,6 @@
 # -*- cperl; cperl-indent-level: 4 -*-
-package WWW::NOS::Open::Exceptions v1.0.3;
+# Copyright (C) 2011-2021, Roland van Ipenburg
+package WWW::NOS::Open::Exceptions v1.0.4;
 use strict;
 use warnings;
 
@@ -20,7 +21,7 @@ __END__
 
 =encoding utf8
 
-=for stopwords Ipenburg MERCHANTABILITY
+=for stopwords Bitbucket Ipenburg MERCHANTABILITY
 
 =head1 NAME
 
@@ -28,7 +29,7 @@ WWW::NOS::Open::Exceptions -  exception information for the Open NOS REST API.
 
 =head1 VERSION
 
-This document describes WWW::NOS::Open::Exceptions version v1.0.3.
+This document describes WWW::NOS::Open::Exceptions version C<v1.0.4>.
 
 =head1 SYNOPSIS
 
@@ -67,15 +68,15 @@ All inherited from L<Exception::Class::Base|Exception::Class::Base/METHODS>.
 =head1 BUGS AND LIMITATIONS
 
 Please report any bugs or feature requests at
-L<RT for rt.cpan.org|https://rt.cpan.org/Dist/Display.html?Queue=WWW-NOS-Open>.
+L<Bitbucket|https://bitbucket.org/rolandvanipenburg/www-nos-open/issues>.
 
 =head1 AUTHOR
 
-Roland van Ipenburg, E<lt>ipenburg@xs4all.nlE<gt>
+Roland van Ipenburg, E<lt>roland@rolandvanipenburg.comE<gt>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2012 by Roland van Ipenburg
+Copyright 2011-2021 by Roland van Ipenburg
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.14.0 or,
