@@ -1,4 +1,6 @@
-package WWW::NOS::Open::Version v1.0.3;   # -*- cperl; cperl-indent-level: 4 -*-
+# -*- cperl; cperl-indent-level: 4 -*-
+# Copyright (C) 2011-2021, Roland van Ipenburg
+package WWW::NOS::Open::Version v1.0.4;
 use strict;
 use warnings;
 
@@ -43,7 +45,7 @@ __END__
 
 =encoding utf8
 
-=for stopwords Ipenburg MERCHANTABILITY
+=for stopwords Bitbucket Ipenburg MERCHANTABILITY
 
 =head1 NAME
 
@@ -51,7 +53,7 @@ WWW::NOS::Open::Version - version of the Open NOS REST API.
 
 =head1 VERSION
 
-This document describes WWW::NOS::Open version v1.0.3.
+This document describes WWW::NOS::Open version C<v1.0.4>.
 
 =head1 SYNOPSIS
 
@@ -65,9 +67,9 @@ This document describes WWW::NOS::Open version v1.0.3.
 
 =over
 
-=item 1. The version number as string, like 'v1'
+=item 1. The version number as string, like C<'v1'>
 
-=item 2. The build number as string, like '0.0.1'
+=item 2. The build number as string, like C<'0.0.1'>
 
 =back
 
@@ -98,15 +100,15 @@ Returns the build number as string.
 =head1 BUGS AND LIMITATIONS
 
 Please report any bugs or feature requests at
-L<RT for rt.cpan.org|https://rt.cpan.org/Dist/Display.html?Queue=WWW-NOS-Open>.
+L<Bitbucket|https://bitbucket.org/rolandvanipenburg/www-nos-open/issues>.
 
 =head1 AUTHOR
 
-Roland van Ipenburg, E<lt>ipenburg@xs4all.nlE<gt>
+Roland van Ipenburg, E<lt>roland@rolandvanipenburg.comE<gt>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2012 by Roland van Ipenburg
+Copyright 2011-2021 by Roland van Ipenburg
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.14.0 or,
